@@ -656,7 +656,7 @@ class Firebot:
         """
         Triggers a given preset effect list. Able to pass in preset args as well.
         """
-        id = self.get_presetEffectID(name)
+        id = self.getPresetEffectID(name)
         if id != None:
             presetarg = {
                 "args": {
@@ -810,7 +810,7 @@ class Firebot:
         """
         Adds currency to all online viewers
         """
-        currencyid = self.get_currencyID(currency)
+        currencyid = self.getCurrencyID(currency)
         data = {
             "effects": {
                 "list": [
@@ -831,7 +831,7 @@ class Firebot:
         """
         Removes currency from all online viewers
         """
-        currencyid = self.get_currencyID(currency)
+        currencyid = self.getCurrencyID(currency)
         data = {
             "effects": {
                 "list": [
@@ -1179,6 +1179,3 @@ class Firebot:
                 return r.json()
             except:
                 attempts += 1
-
-api = Firebot(url='http://192.168.0.35:7472/api/v1')
-print(api.getCustomCommands())
\ No newline at end of file
